@@ -5,6 +5,10 @@ from django.utils.encoding import force_unicode
 from fsfield import settings
 
 
+# Storage instances
+_storage_cache = {}
+
+
 def path_hash(value):
     """
     Get the hash used to store something named *value* in the filesystem.
@@ -35,3 +39,16 @@ def model_instance_field_path(instance, field_name):
         instance._meta.object_name, 
         hashed_path(instance.pk, settings.PATHS_DEPTH),
         field_name)
+
+
+def default_storage():
+    """
+    Get the default storage instance configured in settings.
+    """
+    args, kwargs = settings.DEFAULT_STORAGE_ARGS
+    key = (settings.DEFAULT_STORAGE_CLASS, tuple(args), tuple(kwargs.items()))
+    if key not in _storage_cache:
+        module, cls_name = settings.DEFAULT_STORAGE_CLASS.rsplit(".", 1)
+        cls = getattr(__import__(module, {}, {}, cls_name), cls_name)
+        _storage_cache[key] = cls(*args, **kwargs)
+    return _storage_cache[key]
